@@ -31,12 +31,12 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_ec2
-import aws_cdk.aws_elasticloadbalancingv2
-import aws_cdk.aws_globalaccelerator
+import aws_cdk.aws_ec2 as _aws_cdk_aws_ec2_67de8e8d
+import aws_cdk.aws_elasticloadbalancingv2 as _aws_cdk_aws_elasticloadbalancingv2_e93c784f
+import aws_cdk.aws_globalaccelerator as _aws_cdk_aws_globalaccelerator_190af6ad
 
 
-@jsii.implements(aws_cdk.aws_globalaccelerator.IEndpoint)
+@jsii.implements(_aws_cdk_aws_globalaccelerator_190af6ad.IEndpoint)
 class ApplicationLoadBalancerEndpoint(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-globalaccelerator-endpoints.ApplicationLoadBalancerEndpoint",
@@ -63,7 +63,7 @@ class ApplicationLoadBalancerEndpoint(
 
     def __init__(
         self,
-        load_balancer: aws_cdk.aws_elasticloadbalancingv2.IApplicationLoadBalancer,
+        load_balancer: _aws_cdk_aws_elasticloadbalancingv2_e93c784f.IApplicationLoadBalancer,
         *,
         preserve_client_ip: typing.Optional[builtins.bool] = None,
         weight: typing.Optional[jsii.Number] = None,
@@ -74,14 +74,7 @@ class ApplicationLoadBalancerEndpoint(
         :param weight: Endpoint weight across all endpoints in the group. Must be a value between 0 and 255. Default: 128
         '''
         if __debug__:
-            def stub(
-                load_balancer: aws_cdk.aws_elasticloadbalancingv2.IApplicationLoadBalancer,
-                *,
-                preserve_client_ip: typing.Optional[builtins.bool] = None,
-                weight: typing.Optional[jsii.Number] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__8669e7d6806fa77eb6630b41b033804c1eb287ca70e14d8609f10474b0973946)
             check_type(argname="argument load_balancer", value=load_balancer, expected_type=type_hints["load_balancer"])
         options = ApplicationLoadBalancerEndpointOptions(
             preserve_client_ip=preserve_client_ip, weight=weight
@@ -139,16 +132,10 @@ class ApplicationLoadBalancerEndpointOptions:
             )
         '''
         if __debug__:
-            def stub(
-                *,
-                preserve_client_ip: typing.Optional[builtins.bool] = None,
-                weight: typing.Optional[jsii.Number] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__7ef75e5fe1e4eb51043ef6048bb94dec2e822d6d4e6e5f15e4478a3d0287fd2a)
             check_type(argname="argument preserve_client_ip", value=preserve_client_ip, expected_type=type_hints["preserve_client_ip"])
             check_type(argname="argument weight", value=weight, expected_type=type_hints["weight"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if preserve_client_ip is not None:
             self._values["preserve_client_ip"] = preserve_client_ip
         if weight is not None:
@@ -192,7 +179,7 @@ class ApplicationLoadBalancerEndpointOptions:
         )
 
 
-@jsii.implements(aws_cdk.aws_globalaccelerator.IEndpoint)
+@jsii.implements(_aws_cdk_aws_globalaccelerator_190af6ad.IEndpoint)
 class CfnEipEndpoint(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-globalaccelerator-endpoints.CfnEipEndpoint",
@@ -218,7 +205,7 @@ class CfnEipEndpoint(
 
     def __init__(
         self,
-        eip: aws_cdk.aws_ec2.CfnEIP,
+        eip: _aws_cdk_aws_ec2_67de8e8d.CfnEIP,
         *,
         weight: typing.Optional[jsii.Number] = None,
     ) -> None:
@@ -227,13 +214,7 @@ class CfnEipEndpoint(
         :param weight: Endpoint weight across all endpoints in the group. Must be a value between 0 and 255. Default: 128
         '''
         if __debug__:
-            def stub(
-                eip: aws_cdk.aws_ec2.CfnEIP,
-                *,
-                weight: typing.Optional[jsii.Number] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__287619a8669023400fdb2afd6ffe1519b66f19ff980eca88f05935fcccb370ad)
             check_type(argname="argument eip", value=eip, expected_type=type_hints["eip"])
         options = CfnEipEndpointProps(weight=weight)
 
@@ -282,11 +263,9 @@ class CfnEipEndpointProps:
             )
         '''
         if __debug__:
-            def stub(*, weight: typing.Optional[jsii.Number] = None) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__5d065021e0387ea2eabe863134a7b01f3ebf04904b4cb419dbc38dfd6b4bb7c1)
             check_type(argname="argument weight", value=weight, expected_type=type_hints["weight"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if weight is not None:
             self._values["weight"] = weight
 
@@ -313,7 +292,7 @@ class CfnEipEndpointProps:
         )
 
 
-@jsii.implements(aws_cdk.aws_globalaccelerator.IEndpoint)
+@jsii.implements(_aws_cdk_aws_globalaccelerator_190af6ad.IEndpoint)
 class InstanceEndpoint(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-globalaccelerator-endpoints.InstanceEndpoint",
@@ -340,7 +319,7 @@ class InstanceEndpoint(
 
     def __init__(
         self,
-        instance: aws_cdk.aws_ec2.IInstance,
+        instance: _aws_cdk_aws_ec2_67de8e8d.IInstance,
         *,
         preserve_client_ip: typing.Optional[builtins.bool] = None,
         weight: typing.Optional[jsii.Number] = None,
@@ -351,14 +330,7 @@ class InstanceEndpoint(
         :param weight: Endpoint weight across all endpoints in the group. Must be a value between 0 and 255. Default: 128
         '''
         if __debug__:
-            def stub(
-                instance: aws_cdk.aws_ec2.IInstance,
-                *,
-                preserve_client_ip: typing.Optional[builtins.bool] = None,
-                weight: typing.Optional[jsii.Number] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__e733c2b4b0555bcda9d5526e6c2b88e2fd9f6f1160fd300e8817c08c2e383ed5)
             check_type(argname="argument instance", value=instance, expected_type=type_hints["instance"])
         options = InstanceEndpointProps(
             preserve_client_ip=preserve_client_ip, weight=weight
@@ -416,16 +388,10 @@ class InstanceEndpointProps:
             )
         '''
         if __debug__:
-            def stub(
-                *,
-                preserve_client_ip: typing.Optional[builtins.bool] = None,
-                weight: typing.Optional[jsii.Number] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__e26e8bcdffc47d59449f78f33f29e383f72c325d97974d2fde13dac8f6acfeb7)
             check_type(argname="argument preserve_client_ip", value=preserve_client_ip, expected_type=type_hints["preserve_client_ip"])
             check_type(argname="argument weight", value=weight, expected_type=type_hints["weight"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if preserve_client_ip is not None:
             self._values["preserve_client_ip"] = preserve_client_ip
         if weight is not None:
@@ -469,7 +435,7 @@ class InstanceEndpointProps:
         )
 
 
-@jsii.implements(aws_cdk.aws_globalaccelerator.IEndpoint)
+@jsii.implements(_aws_cdk_aws_globalaccelerator_190af6ad.IEndpoint)
 class NetworkLoadBalancerEndpoint(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-globalaccelerator-endpoints.NetworkLoadBalancerEndpoint",
@@ -511,7 +477,7 @@ class NetworkLoadBalancerEndpoint(
 
     def __init__(
         self,
-        load_balancer: aws_cdk.aws_elasticloadbalancingv2.INetworkLoadBalancer,
+        load_balancer: _aws_cdk_aws_elasticloadbalancingv2_e93c784f.INetworkLoadBalancer,
         *,
         weight: typing.Optional[jsii.Number] = None,
     ) -> None:
@@ -520,13 +486,7 @@ class NetworkLoadBalancerEndpoint(
         :param weight: Endpoint weight across all endpoints in the group. Must be a value between 0 and 255. Default: 128
         '''
         if __debug__:
-            def stub(
-                load_balancer: aws_cdk.aws_elasticloadbalancingv2.INetworkLoadBalancer,
-                *,
-                weight: typing.Optional[jsii.Number] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__0bc312528db06124b633a8e77bceb3402e3f417009243a5381fe9e2bdcf0f80d)
             check_type(argname="argument load_balancer", value=load_balancer, expected_type=type_hints["load_balancer"])
         options = NetworkLoadBalancerEndpointProps(weight=weight)
 
@@ -575,11 +535,9 @@ class NetworkLoadBalancerEndpointProps:
             )
         '''
         if __debug__:
-            def stub(*, weight: typing.Optional[jsii.Number] = None) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__109ebfda5a3d8d710c464a172b0d22502fb3442863caae960d99f893d95dc140)
             check_type(argname="argument weight", value=weight, expected_type=type_hints["weight"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if weight is not None:
             self._values["weight"] = weight
 
@@ -618,3 +576,67 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__8669e7d6806fa77eb6630b41b033804c1eb287ca70e14d8609f10474b0973946(
+    load_balancer: _aws_cdk_aws_elasticloadbalancingv2_e93c784f.IApplicationLoadBalancer,
+    *,
+    preserve_client_ip: typing.Optional[builtins.bool] = None,
+    weight: typing.Optional[jsii.Number] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7ef75e5fe1e4eb51043ef6048bb94dec2e822d6d4e6e5f15e4478a3d0287fd2a(
+    *,
+    preserve_client_ip: typing.Optional[builtins.bool] = None,
+    weight: typing.Optional[jsii.Number] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__287619a8669023400fdb2afd6ffe1519b66f19ff980eca88f05935fcccb370ad(
+    eip: _aws_cdk_aws_ec2_67de8e8d.CfnEIP,
+    *,
+    weight: typing.Optional[jsii.Number] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5d065021e0387ea2eabe863134a7b01f3ebf04904b4cb419dbc38dfd6b4bb7c1(
+    *,
+    weight: typing.Optional[jsii.Number] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e733c2b4b0555bcda9d5526e6c2b88e2fd9f6f1160fd300e8817c08c2e383ed5(
+    instance: _aws_cdk_aws_ec2_67de8e8d.IInstance,
+    *,
+    preserve_client_ip: typing.Optional[builtins.bool] = None,
+    weight: typing.Optional[jsii.Number] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e26e8bcdffc47d59449f78f33f29e383f72c325d97974d2fde13dac8f6acfeb7(
+    *,
+    preserve_client_ip: typing.Optional[builtins.bool] = None,
+    weight: typing.Optional[jsii.Number] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__0bc312528db06124b633a8e77bceb3402e3f417009243a5381fe9e2bdcf0f80d(
+    load_balancer: _aws_cdk_aws_elasticloadbalancingv2_e93c784f.INetworkLoadBalancer,
+    *,
+    weight: typing.Optional[jsii.Number] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__109ebfda5a3d8d710c464a172b0d22502fb3442863caae960d99f893d95dc140(
+    *,
+    weight: typing.Optional[jsii.Number] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
